@@ -36,7 +36,7 @@
 #include <libxfdashboard/utils.h>
 #include <libxfdashboard/application-tracker.h>
 #include <libxfdashboard/stylable.h>
-#include <libxfdashboard/application.h>
+#include <libxfdashboard/core.h>
 #include <libxfdashboard/window-tracker.h>
 #include <libxfdashboard/popup-menu-item-button.h>
 #include <libxfdashboard/popup-menu-item-separator.h>
@@ -218,7 +218,7 @@ static void _xfdashboard_application_button_on_popup_menu_item_activate_window(X
 	xfdashboard_window_tracker_window_activate(window);
 
 	/* Quit application */
-	xfdashboard_application_suspend_or_quit(NULL);
+	xfdashboard_core_quit(NULL);
 }
 
 /* User selected to execute an application action */
@@ -284,7 +284,7 @@ static void _xfdashboard_application_button_on_popup_menu_item_application_actio
 								g_app_info_get_display_name(priv->appInfo));
 
 			/* Quit application */
-			xfdashboard_application_suspend_or_quit(NULL);
+			xfdashboard_core_quit(NULL);
 
 			/* Release allocated resources */
 			g_object_unref(gicon);
@@ -473,7 +473,7 @@ static void xfdashboard_application_button_init(XfdashboardApplicationButton *se
 	priv->showDescription=FALSE;
 	priv->formatTitleOnly=NULL;
 	priv->formatTitleDescription=NULL;
-	priv->appTracker=xfdashboard_application_tracker_get_default();
+	priv->appTracker=xfdashboard_core_get_application_tracker(NULL);
 	priv->runningStateChangedID=0;
 
 	/* Connect signals */
@@ -775,7 +775,7 @@ gboolean xfdashboard_application_button_execute(XfdashboardApplicationButton *se
 								xfdashboard_application_button_get_display_name(self));
 
 			/* Emit signal for successful application launch */
-			g_signal_emit_by_name(xfdashboard_application_get_default(), "application-launched", priv->appInfo);
+			g_signal_emit_by_name(xfdashboard_core_get_default(), "application-launched", priv->appInfo);
 
 			/* Set status that application has been started successfully */
 			started=TRUE;
@@ -820,7 +820,7 @@ guint xfdashboard_application_button_add_popup_menu_items_for_windows(Xfdashboar
 		 * of list if it is on active workspace and to end of list if it
 		 * is on any other workspace.
 		 */
-		windowTracker=xfdashboard_window_tracker_get_default();
+		windowTracker=xfdashboard_core_get_window_tracker(NULL);
 		activeWorkspace=xfdashboard_window_tracker_get_active_workspace(windowTracker);
 
 		sortedList=NULL;
