@@ -28,6 +28,7 @@
 
 #include <glib/gi18n-lib.h>
 
+#include <libxfdashboard/core.h>
 #include <libxfdashboard/application-database.h>
 #include <libxfdashboard/desktop-app-info.h>
 #include <libxfdashboard/compat.h>
@@ -82,9 +83,6 @@ static guint XfdashboardApplicationDatabaseSignals[SIGNAL_LAST]={ 0, };
 
 /* IMPLEMENTATION: Private variables and methods */
 
-/* Single instance of application database */
-static XfdashboardApplicationDatabase*		_xfdashboard_application_database=NULL;
-
 typedef struct _XfdashboardApplicationDatabaseFileMonitorData	XfdashboardApplicationDatabaseFileMonitorData;
 struct _XfdashboardApplicationDatabaseFileMonitorData
 {
@@ -1267,26 +1265,6 @@ static void _xfdashboard_application_database_check_search_path_duplicate(gpoint
 
 /* IMPLEMENTATION: GObject */
 
-/* Construct this object */
-static GObject* _xfdashboard_application_database_constructor(GType inType,
-																guint inNumberConstructParams,
-																GObjectConstructParam *inConstructParams)
-{
-	GObject									*object;
-
-	if(!_xfdashboard_application_database)
-	{
-		object=G_OBJECT_CLASS(xfdashboard_application_database_parent_class)->constructor(inType, inNumberConstructParams, inConstructParams);
-		_xfdashboard_application_database=XFDASHBOARD_APPLICATION_DATABASE(object);
-	}
-		else
-		{
-			object=g_object_ref(G_OBJECT(_xfdashboard_application_database));
-		}
-
-	return(object);
-}
-
 /* Dispose this object */
 static void _xfdashboard_application_database_dispose(GObject *inObject)
 {
@@ -1306,19 +1284,6 @@ static void _xfdashboard_application_database_dispose(GObject *inObject)
 	G_OBJECT_CLASS(xfdashboard_application_database_parent_class)->dispose(inObject);
 }
 
-/* Finalize this object */
-static void _xfdashboard_application_database_finalize(GObject *inObject)
-{
-	/* Release allocated resources finally, e.g. unset singleton */
-	if(G_LIKELY(G_OBJECT(_xfdashboard_application_database)==inObject))
-	{
-		_xfdashboard_application_database=NULL;
-	}
-
-	/* Call parent's class dispose method */
-	G_OBJECT_CLASS(xfdashboard_application_database_parent_class)->finalize(inObject);
-}
-
 /* Set/get properties */
 static void _xfdashboard_application_database_get_property(GObject *inObject,
 															guint inPropID,
@@ -1349,9 +1314,7 @@ static void xfdashboard_application_database_class_init(XfdashboardApplicationDa
 	GObjectClass		*gobjectClass=G_OBJECT_CLASS(klass);
 
 	/* Override functions */
-	gobjectClass->constructor=_xfdashboard_application_database_constructor;
 	gobjectClass->dispose=_xfdashboard_application_database_dispose;
-	gobjectClass->finalize=_xfdashboard_application_database_finalize;
 	gobjectClass->get_property=_xfdashboard_application_database_get_property;
 
 	/* Define properties */
@@ -1459,15 +1422,6 @@ static void xfdashboard_application_database_init(XfdashboardApplicationDatabase
 
 /* IMPLEMENTATION: Public API */
 
-/* Get single instance of application */
-XfdashboardApplicationDatabase* xfdashboard_application_database_get_default(void)
-{
-	GObject									*singleton;
-
-	singleton=g_object_new(XFDASHBOARD_TYPE_APPLICATION_DATABASE, NULL);
-	return(XFDASHBOARD_APPLICATION_DATABASE(singleton));
-}
-
 /* Determine if menu and applications has been loaded successfully */
 gboolean xfdashboard_application_database_is_loaded(const XfdashboardApplicationDatabase *self)
 {
@@ -1612,7 +1566,7 @@ gchar* xfdashboard_application_database_get_file_from_desktop_id(const gchar *in
 	g_return_val_if_fail(inDesktopID && *inDesktopID, NULL);
 
 	/* Get singleton of application database */
-	appDB=xfdashboard_application_database_get_default();
+	appDB=xfdashboard_core_get_application_database(NULL);
 
 	/* Requested desktop ID must have ".desktop" suffix */
 	if(!g_str_has_suffix(inDesktopID, ".desktop"))
@@ -1787,7 +1741,7 @@ gchar* xfdashboard_application_database_get_desktop_id_from_path(const gchar *in
 	foundDesktopID=NULL;
 
 	/* Get singleton of application database */
-	appDB=xfdashboard_application_database_get_default();
+	appDB=xfdashboard_core_get_application_database(NULL);
 
 	/* Get search paths */
 	searchPaths=xfdashboard_application_database_get_application_search_paths(appDB);
