@@ -47,7 +47,7 @@ struct _XfdashboardBackgroundPrivate
 	XfdashboardCorners			fillCorners;
 	gfloat						fillCornersRadius;
 
-	ClutterColor				*outlineColor;
+	XfdashboardGradientColor		*outlineColor;
 	gfloat						outlineWidth;
 	XfdashboardBorders			outlineBorders;
 	XfdashboardCorners			outlineCorners;
@@ -257,7 +257,7 @@ static void _xfdashboard_background_dispose(GObject *inObject)
 
 	if(priv->outlineColor)
 	{
-		clutter_color_free(priv->outlineColor);
+		xfdashboard_gradient_color_free(priv->outlineColor);
 		priv->outlineColor=NULL;
 	}
 
@@ -306,7 +306,7 @@ static void _xfdashboard_background_set_property(GObject *inObject,
 			break;
 
 		case PROP_OUTLINE_COLOR:
-			xfdashboard_background_set_outline_color(self, clutter_value_get_color(inValue));
+			xfdashboard_background_set_outline_color(self, g_value_get_boxed(inValue));
 			break;
 
 		case PROP_OUTLINE_WIDTH:
@@ -362,7 +362,7 @@ static void _xfdashboard_background_get_property(GObject *inObject,
 			break;
 
 		case PROP_OUTLINE_COLOR:
-			clutter_value_set_color(outValue, priv->outlineColor);
+			g_value_set_boxed(outValue, priv->outlineColor);
 			break;
 
 		case PROP_OUTLINE_WIDTH:
@@ -397,9 +397,16 @@ static void _xfdashboard_background_get_property(GObject *inObject,
  */
 static void xfdashboard_background_class_init(XfdashboardBackgroundClass *klass)
 {
-	XfdashboardActorClass	*actorClass=XFDASHBOARD_ACTOR_CLASS(klass);
-	ClutterActorClass		*clutterActorClass=CLUTTER_ACTOR_CLASS(klass);
-	GObjectClass			*gobjectClass=G_OBJECT_CLASS(klass);
+	XfdashboardActorClass			*actorClass=XFDASHBOARD_ACTOR_CLASS(klass);
+	ClutterActorClass				*clutterActorClass=CLUTTER_ACTOR_CLASS(klass);
+	GObjectClass					*gobjectClass=G_OBJECT_CLASS(klass);
+	static XfdashboardGradientColor	*defaultColor=NULL;
+
+	/* Set up default value for param spec */
+	if(G_UNLIKELY(!defaultColor))
+	{
+		defaultColor=xfdashboard_gradient_color_new_solid(CLUTTER_COLOR_White);
+	}
 
 	/* Override functions */
 	gobjectClass->dispose=_xfdashboard_background_dispose;
@@ -458,11 +465,11 @@ static void xfdashboard_background_class_init(XfdashboardBackgroundClass *klass)
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardBackgroundProperties[PROP_OUTLINE_COLOR]=
-		clutter_param_spec_color("outline-color",
-									"Outline color",
-									"Color to draw outline with",
-									CLUTTER_COLOR_White,
-									G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+		xfdashboard_param_spec_gradient_color("outline-color",
+											"Outline color",
+											"Color to draw outline with",
+											defaultColor,
+											G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardBackgroundProperties[PROP_OUTLINE_WIDTH]=
 		g_param_spec_float("outline-width",
@@ -541,7 +548,7 @@ static void xfdashboard_background_init(XfdashboardBackground *self)
 	priv->fillCornersRadius=0.0f;
 
 	priv->outline=XFDASHBOARD_OUTLINE_EFFECT(g_object_ref(xfdashboard_outline_effect_new()));
-	priv->outlineColor=clutter_color_copy(CLUTTER_COLOR_White);
+	priv->outlineColor=xfdashboard_gradient_color_new_solid(CLUTTER_COLOR_White);
 	priv->outlineWidth=1.0f;
 	priv->outlineCorners=XFDASHBOARD_CORNERS_ALL;
 	priv->outlineBorders=XFDASHBOARD_BORDERS_ALL;
@@ -726,14 +733,14 @@ void xfdashboard_background_set_fill_corner_radius(XfdashboardBackground *self,
 }
 
 /* Get/set color to draw outline with */
-const ClutterColor* xfdashboard_background_get_outline_color(XfdashboardBackground *self)
+const XfdashboardGradientColor* xfdashboard_background_get_outline_color(XfdashboardBackground *self)
 {
 	g_return_val_if_fail(XFDASHBOARD_IS_BACKGROUND(self), NULL);
 
 	return(self->priv->outlineColor);
 }
 
-void xfdashboard_background_set_outline_color(XfdashboardBackground *self, const ClutterColor *inColor)
+void xfdashboard_background_set_outline_color(XfdashboardBackground *self, const XfdashboardGradientColor *inColor)
 {
 	XfdashboardBackgroundPrivate	*priv;
 
@@ -743,14 +750,15 @@ void xfdashboard_background_set_outline_color(XfdashboardBackground *self, const
 	priv=self->priv;
 
 	/* Set value if changed */
-	if(priv->outlineColor==NULL || clutter_color_equal(inColor, priv->outlineColor)==FALSE)
+	if(priv->outlineColor==NULL ||
+		!xfdashboard_gradient_color_equal(inColor, priv->outlineColor))
 	{
 		/* Set value */
-		if(priv->outlineColor) clutter_color_free(priv->outlineColor);
-		priv->outlineColor=clutter_color_copy(inColor);
+		if(priv->outlineColor) xfdashboard_gradient_color_free(priv->outlineColor);
+		priv->outlineColor=xfdashboard_gradient_color_copy(inColor);
 
 		/* Update effect */
-		if(priv->outline) xfdashboard_outline_effect_set_color(priv->outline, inColor);
+		if(priv->outline) xfdashboard_outline_effect_set_color(priv->outline, priv->outlineColor);
 
 		/* Notify about property change */
 		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardBackgroundProperties[PROP_OUTLINE_COLOR]);
@@ -791,7 +799,7 @@ void xfdashboard_background_set_outline_width(XfdashboardBackground *self, const
 /* Get/set sides of border of outline to draw rounded when drawing outline */
 XfdashboardBorders xfdashboard_background_get_outline_borders(XfdashboardBackground *self)
 {
-	g_return_val_if_fail(XFDASHBOARD_IS_BACKGROUND(self), XFDASHBOARD_CORNERS_NONE);
+	g_return_val_if_fail(XFDASHBOARD_IS_BACKGROUND(self), XFDASHBOARD_BORDERS_NONE);
 
 	return(self->priv->outlineBorders);
 }
