@@ -2,7 +2,7 @@
  * background: An actor providing background rendering. Usually other
  *             actors are derived from this one.
  * 
- * Copyright 2012-2019 Stephan Haller <nomad@froevel.de>
+ * Copyright 2012-2020 Stephan Haller <nomad@froevel.de>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #include <clutter/clutter.h>
 
 #include <libxfdashboard/actor.h>
+#include <libxfdashboard/gradient-color.h>
 #include <libxfdashboard/types.h>
 
 G_BEGIN_DECLS
@@ -68,7 +69,12 @@ typedef struct _XfdashboardBackground				XfdashboardBackground;
 typedef struct _XfdashboardBackgroundClass			XfdashboardBackgroundClass;
 typedef struct _XfdashboardBackgroundPrivate		XfdashboardBackgroundPrivate;
 
-struct _XfdashboardBackground
+/**
+ * XfdashboardBackground:
+ *
+ * The #XfdashboardBackground structure contains only private data and
+ * should be accessed using the provided API
+ */struct _XfdashboardBackground
 {
 	/*< private >*/
 	/* Parent instance */
@@ -78,6 +84,11 @@ struct _XfdashboardBackground
 	XfdashboardBackgroundPrivate	*priv;
 };
 
+/**
+ * XfdashboardBackgroundClass:
+ *
+ * The #XfdashboardBackgroundClass structure contains only private data
+ */
 struct _XfdashboardBackgroundClass
 {
 	/*< private >*/
@@ -111,8 +122,8 @@ gfloat xfdashboard_background_get_fill_corner_radius(XfdashboardBackground *self
 void xfdashboard_background_set_fill_corner_radius(XfdashboardBackground *self, const gfloat inRadius);
 
 /* Outline functions */
-const ClutterColor* xfdashboard_background_get_outline_color(XfdashboardBackground *self);
-void xfdashboard_background_set_outline_color(XfdashboardBackground *self, const ClutterColor *inColor);
+const XfdashboardGradientColor* xfdashboard_background_get_outline_color(XfdashboardBackground *self);
+void xfdashboard_background_set_outline_color(XfdashboardBackground *self, const XfdashboardGradientColor *inColor);
 
 gfloat xfdashboard_background_get_outline_width(XfdashboardBackground *self);
 void xfdashboard_background_set_outline_width(XfdashboardBackground *self, const gfloat inWidth);
